import typing
import collections.abc
import typing_extensions
import bgui.widget

class TextBlock(bgui.widget.Widget):
    """Widget for displaying blocks of text"""

    children: typing.Any
    on_active: typing.Any
    on_click: typing.Any
    on_hover: typing.Any
    on_mouse_enter: typing.Any
    on_mouse_exit: typing.Any
    on_release: typing.Any
    parent: typing.Any
    position: typing.Any
    size: typing.Any
    system: typing.Any
    text: typing.Any
    theme_options: typing.Any
    theme_section: typing.Any
